@@ -66,13 +66,13 @@ few material changes.
 
 Flavio Poletti added the SQLite support.
 
-Maintained by brian d foy, C<< <bdfoy@cpan.org> >>
+Maintained by brian d foy, C<< <briandfoy@pobox.com> >>
 
 =head1 COPYRIGHT AND LICENSE
 
 Parts Copyright 1997-1999 Gisle Aas.
 
-Other parts Copyright 2018-2019 by brian d foy, C<< <bdfoy@cpan.org> >>
+Other parts Copyright 2018-2024 by brian d foy, C<< <briandfoy@pobox.com> >>
 
 This library is free software; you can redistribute it and/or modify
 it under the terms of the Artistic License 2.0.
@@ -87,15 +87,14 @@ use Carp qw(carp);
 use constant TRUE  => 'TRUE';
 use constant FALSE => 'FALSE';
 
-$VERSION = '2.036';
+$VERSION = '3.001';
 $SQLITE = 'sqlite3';
 
 
 sub _load_ff3 {
 	my ($self, $file) = @_;
 	my $cookies;
-	my $query = 'SELECT host, path, name, value, isSecure, expiry '
-	  . ' FROM moz_cookies';
+	my $query = 'SELECT host, path, name, value, isSecure, expiry FROM moz_cookies';
 	eval {
 		require DBI;
 		my $dbh = DBI->connect('dbi:SQLite:dbname=' . $file, '', '',
